# Basics

## Basic project website content

[contribution]

    : <https://github.com/makukha/pydantic-file-secrets/blob/main/.github/CONTRIBUTING.md>

[contribution_requirements]

    : <https://github.com/makukha/pydantic-file-secrets/blob/main/.github/CONTRIBUTING.md>

## Documentation

[documentation_basics]

    : <https://github.com/makukha/pydantic-file-secrets>

[documentation_interface]

    : <https://github.com/makukha/pydantic-file-secrets>


# Change control

## Public version-controlled source repository

[repo_interim]

    : Interim project version is the "main" branch of the project. Changes are made by merging pull requests, after that the "main" branch can be used for review and independent deployment. Source code for the main branch is available at <https://github.com/makukha/pydantic-file-secrets/archive/refs/heads/main.zip>

## Unique version numbering

[version_unique]

    : This project adheres to Semantic Versioning. Release versions are included in project changelog: <https://github.com/makukha/pydantic-file-secrets/blob/main/CHANGELOG.md>

[version_tags]

    : Every release has corresponding version tag: <https://github.com/makukha/pydantic-file-secrets/tags>


# Reporting

## Bug-reporting process

[report_process]

    : Bug reports are submitted using project issue tracker: <https://github.com/makukha/pydantic-file-secrets/issues>

[report_archive]

    : All closed bug reports and responses are available in project issue tracker: <https://github.com/makukha/pydantic-file-secrets/issues?q=is%3Aissue%20state%3Aclosed>

## Vulnerability report process

[vulnerability_report_process]

    : The process for vulnerability reporting is described in Security Policy: <https://github.com/makukha/pydantic-file-secrets/blob/main/.github/SECURITY.md>

[vulnerability_report_private]

    : All vulnerability reports are private and submitted using the GitHub Security Advisory <https://github.com/makukha/pydantic-file-secrets/security/advisories/new>


# Quality

## Automated test suite

[test_continuous_integration]

    : Tests are run manually in feature branches and are guarantee to be run in release branches.


# Analysis

## Static code analysis

[static_analysis]

    : mypy, Ruff
